-- 每日礼包
Lua_DailyGiftPanel = class("Lua_DailyGiftPanel", Lua_DisplayObject);
function Lua_DailyGiftPanel:ctor(p)
	self:superCall("ctor", p, "DailyGiftPanel_skin");
end

function Lua_DailyGiftPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.giftList = Lua_DragList.new(self.content, 675, 800 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.giftList.tweenId = 2016;
	self.giftList:setListCell(Lua_DailyGiftItem, 225, 304, 3);
	self.giftList:setCellSpacing(0, 7);
	self.giftList:setLocation(0, -41, 0);

	self:addLuaEvent("UPDATE_DAILYGIFT_INFO", self, self.updateGiftInfo);
	Lua_ProxyManager.getProxy("Lua_RaccoonMartProxy"):sDailyGiftInInfo();
end

function Lua_DailyGiftPanel:setData(data)
end

function Lua_DailyGiftPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.giftList:setContentRect(675, 800 + adaptHeight);
end

function Lua_DailyGiftPanel:updateGiftInfo()
	self.giftList:setArrayData(DataCenter.dailyGiftData.dailyGiftArr);
	self:startTimer();
	self:updateLeftTime();
end

function Lua_DailyGiftPanel:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("Lua_DailyGiftPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_DailyGiftPanel:updateLeftTime()
	local time = DataCenter.dailyGiftData.nextDay - DataCenter.roleData.serverTime;
	if time <= 0 then
		self.leftTimeTxt.text = LanUtil.formateStr(202700, LanUtil.getValue(202701));
		self:endTimer();
		return;
	end
	self.leftTimeTxt.text = LanUtil.formateStr(202700, Lua_TimeTransform.transSeconds1(time, true, true, true));
end

function Lua_DailyGiftPanel:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

function Lua_DailyGiftPanel:dispose()
	if self.giftList ~= nil then
		self.giftList:dispose();
		self.giftList = nil;
	end
	self:endTimer();
	self:superCall("dispose");
end










Lua_DailyGiftItem = class("Lua_DailyGiftItem", Lua_ListCell);
function Lua_DailyGiftItem:ctor(p)
	self:superCall("ctor", p, "DailyGiftItem_skin");
end

function Lua_DailyGiftItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemWidth = 124; -- 道具背景大小
	self.rewardList = Lua_DragList.new(self.content, 195, 62, Lua_AxisDefine.Horizontal);
	self.rewardList:setLocation(0, -25, 0);
	self:setSubList(self.rewardList);
end

function Lua_DailyGiftItem:setData(data)
	self._data = DataCenter.dailyGiftData:getDailyGiftVo(data);
	if data == nil or self._data == nil then
		return;
	end

	self.giftIcon:setAltas(self._data.reward_icon[1], self._data.reward_icon[2]);
	self.timesTxt.text = LanUtil.formateStr(202702, self._data.curLimitTimes, self._data.limit_times);

	if self._data.money == 0 then
		self.moneyTxt:setLangValue(202703);
	else
		self.moneyTxt.text = LanUtil.formateStr(202704, self._data.money);
	end

	local rewardInfo = self._data.reward;
	local list = {};
	for i = 1, #rewardInfo do
		list[i] = {reward = rewardInfo[i], rate = self._data.rate, times = self._data.curLimitTimes};
	end
	local cellWidth;
	local width;
	if #rewardInfo < 4 then
		cellWidth = 65;
		width =  #rewardInfo > 2 and 195 or #rewardInfo * 65;
	else
		cellWidth = 50;
		width = cellWidth * 4;
	end
	self.rewardList.canDrag = #rewardInfo > 4;
	self.rewardList:setListCell(Lua_DailyGiftSubItem, cellWidth, self.itemWidth * self._data.rate, 1);
	self.rewardList:setContentRect(width, self.itemWidth * self._data.rate);
	self.rewardList:setArrayData(list);

	self.itemBg:setGray(self._data.curLimitTimes <= 0);
	self.giftIcon:setGray(self._data.curLimitTimes <= 0);
	self.selloutIcon:setEnable(self._data.curLimitTimes <= 0);
	self:showRedDot(self._data.money == 0 and self._data.curLimitTimes > 0);
end

function Lua_DailyGiftItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(85, 125, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_DailyGiftItem:onPressClick()
	if self._data == nil then
		return;
	end
	
	local item;
	local winPos = LuaUtil.getTouchPosInverseObj(self.rewardList.sub);
	for i = 1, self.rewardList.showList:getSize() do
		item = self.rewardList.showList[i];
		if item ~= nil and item:checkInBound(winPos.x, winPos.y) then
			item:onPressClick();
			return;
		end
	end

	if self._data.curLimitTimes > 0 then
		if self._data.money == 0 then
			Lua_ProxyManager.getProxy("Lua_RaccoonMartProxy"):sGetDailyGiftReward(self._data.id);
		else
			local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(self._data.id);
			DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
				tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
		end
	else
		OperateAlert.showLangValue(202705);
	end
end

function Lua_DailyGiftItem:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end










Lua_DailyGiftSubItem = class("Lua_DailyGiftSubItem", Lua_ListCell);
function Lua_DailyGiftSubItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_DailyGiftSubItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
end

function Lua_DailyGiftSubItem:setData(data)
	if data == nil then
		return;
	end

	local tvo = Lua_ToolVo.createToolVo(data.reward[1], data.reward[2]);
	self.itemIcon:setData(tvo);
	self.itemIcon:setGray(data.times <= 0);
	self.itemIcon:setScale(data.rate, data.rate);
end

function Lua_DailyGiftSubItem:onPressClick()
	if self.itemIcon.data == nil then
		return;
	end
	DataCenter.packUtil:showItemInfo(self.itemIcon.data);
end

function Lua_DailyGiftSubItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:superCall("dispose");
end