Lua_ExclusivePlanLevelBuyWindow = class("Lua_ExclusivePlanLevelBuyWindow", Lua_Window);
function Lua_ExclusivePlanLevelBuyWindow:ctor()
	self:superCall("ctor");

	self.showBlackMask = true;
    self.isClickClose = true;
	self.windowName = "Lua_ExclusivePlanLevelBuyWindow";
	self.skinName = "ExclusivePlanLevelBuyWindow_skin";
end

function Lua_ExclusivePlanLevelBuyWindow:buildShowItem()
	self:superCall("buildShowItem");
    
    self.buyNum = 1;
    self.textInput.defaultText = 1;
    self.curLevel = DataCenter.exclusivePlanData.planLevel;
    self.textInput.contentTypeValue = 2;

    self.rewardList = Lua_DragList.new(self.content, 400, 112, Lua_AxisDefine.Horizontal);
    self.rewardList:setListCell(Lua_ExclusivePlanLevelBuyIconItem, 112, 112, 1);
    self.rewardList:setCellSpacing(4, 0);
    self.rewardList:setLocation(0, 35);

    self.reduceBtn:addClickFuntion(self, self.onReduceBuyNumClick);
    self.addBtn:addClickFuntion(self, self.onAddBuyNumClick);
    self.buyBtn:addClickFuntion(self, self.onBuyLevelClick);
    self.textInput:onChange(self, self.onInputBuyNum);
    self:updateInfo();
end

function Lua_ExclusivePlanLevelBuyWindow:onReduceBuyNumClick()
	if self.buyNum > 1 then
		self.buyNum = self.buyNum - 1;
		self:updateInfo();
	end
end

function Lua_ExclusivePlanLevelBuyWindow:onAddBuyNumClick()
	local maxLevel = #DataCenter.exclusivePlanData.stateList;
	if self.buyNum < maxLevel - self.curLevel then
		self.buyNum = self.buyNum + 1;
		self:updateInfo();
	else
		OperateAlert.showLangValue(450012);
	end
end

function Lua_ExclusivePlanLevelBuyWindow:onInputBuyNum()
	local maxLevel = #DataCenter.exclusivePlanData.stateList;
	if tonumber(self.textInput.text) == nil then
		return;
	end
	if tonumber(self.textInput.text) < 1 then
		self.buyNum = 1;
	elseif tonumber(self.textInput.text) > maxLevel  - self.curLevel then
		self.buyNum = maxLevel  - self.curLevel;
	else
		self.buyNum = tonumber(self.textInput.text);
	end
	self:updateInfo();
end

function Lua_ExclusivePlanLevelBuyWindow:onBuyLevelClick()
	local costNum = DataCenter.exclusivePlanUtil:getLevelNeedExp(self.curLevel + self.buyNum)
	 / DataCenter.exclusivePlanUtil.conversionRate;
	local myMoneyNum = DataCenter.moneyData:getMoney(Lua_ResourcesDefine.DIAMOND);
	if myMoneyNum < costNum then
		DataCenter.packUtil:openPathWindow(Lua_ResourcesDefine.DIAMOND, false);
	else
	    Lua_WindowUtil.openWin("Lua_ExclusivePlanLevelBuyWindow", Lua_WinParam.ACTION_CLOSE);
	end
	Lua_ProxyManager.getProxy("Lua_ExclusivePlanProxy"):sBuyLevel(self.buyNum);
end

function Lua_ExclusivePlanLevelBuyWindow:updateInfo()    
	local costNum = DataCenter.exclusivePlanUtil:getLevelNeedExp(self.curLevel + self.buyNum)
	 / DataCenter.exclusivePlanUtil.conversionRate;
	local myMoneyNum = DataCenter.moneyData:getMoney(Lua_ResourcesDefine.DIAMOND);
	local str;
	if myMoneyNum < costNum then
		str = Lua_ColorDefine.getColorStr("ee4d30", Mathf.Floor(costNum));
	else
		str = Lua_ColorDefine.getColorStr("8F5123", Mathf.Floor(costNum));
	end

	self.costNumTxt.text = str;
	self.costNumTxt:resetSize();
    self.costMoneyIcon:setLocation(-12 - (self.costNumTxt.width - 20) / 2, -193);

	self.textInput.text = self.buyNum;
	self.buyTipsTxt.text = LanUtil.formateStr(450013, self.curLevel + self.buyNum);
	local rewardArr;
	if DataCenter.exclusivePlanData.planType == 1 then
		rewardArr = DataCenter.exclusivePlanUtil:getTwoLevelReward(self.curLevel + 1, self.curLevel + self.buyNum, true, true);
	else
		rewardArr = DataCenter.exclusivePlanUtil:getTwoLevelReward(self.curLevel + 1, self.curLevel + self.buyNum, false, true);
	end
	if rewardArr == nil then
		return;
	end
	local mergeRewardList = DataCenter.exclusivePlanUtil:mergeRewardInfo(rewardArr);
	local width;
	local len = #mergeRewardList;
	if len <= 4 then
		width = 112 * len + 4 * (len - 1);
		self.rewardList.canDrag = false;
	else
		width = 500;
		self.rewardList.canDrag = true;
	end
	self.rewardList:setContentRect(width, 112);
	self.rewardList:setArrayData(mergeRewardList);
	self.rewardList:moveToIndex(1);
end

function Lua_ExclusivePlanLevelBuyWindow:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	
	self:superCall("dispose");
end











Lua_ExclusivePlanLevelBuyIconItem = class("Lua_ExclusivePlanLevelBuyIconItem", Lua_ItemIconCell)
function Lua_ExclusivePlanLevelBuyIconItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ExclusivePlanLevelBuyIconItem:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.9, 0.9);
end

function Lua_ExclusivePlanLevelBuyIconItem:onMouseDownHandle()
	self.itemIcon:setScale(0.855, 0.855);
end

function Lua_ExclusivePlanLevelBuyIconItem:onMouseUpHandle()
	self.itemIcon:setScale(0.9, 0.9);
end