-- 钓鱼-特权
Lua_GoFishingPrivilegePanel = class("Lua_GoFishingPrivilegePanel", Lua_DisplayObject)
function Lua_GoFishingPrivilegePanel:ctor(p)
	self:superCall("ctor", p, "GoFishingPrivilegePanel_skin");
end

function Lua_GoFishingPrivilegePanel:buildShowItem()
	self:superCall("buildShowItem");
	self.rechargeId = DataCenter.goFishingUtil:getGoFishingPrivilegeConfig("recharge_id", 1);
	local framItemId = DataCenter.goFishingUtil:getGoFishingPrivilegeConfig("item_id", 1);
	if framItemId > 0 then
		self.decSp_1:setEnable(true);
		self.decSp_2:setEnable(true);
		local config = getConfig("item", framItemId);
		self.decSp_2:setAltas(config.atlas, config.sprite);
	else
		self.decSp_1:setEnable(false);
		self.decSp_2:setEnable(false);
	end

	local arr = DataCenter.goFishingUtil.privilegeDesList;
	local len = arr:getSize();
	local width = 31 * len + 15 * (len - 1);
	self.desList = Lua_DragList.new(self.tweenObject, 570, width, Lua_AxisDefine.Vertical);
	self.desList:setSiblingIndex(1);
	self.desList:setRectPivot(1);
	self.desList:setLocation(13, 224.5, 0);
	self.desList:setListCell(Lua_GoFishingPrivilegeItem, 570, 31, 1);
	self.desList:setCellSpacing(0, 15);
	self.desList.canDrag = false;
	self.desList:setArrayData(arr);

	local reward = DataCenter.goFishingUtil:getGoFishingPrivilegeConfig("reward", 4);
	if reward and #reward > 0 then
		self.getObject:SetActive(true);
		LuaUtil.setObjPos(self.getObject, -218, 224.5 - width - 45.5, 0);

		self.itemList = Lua_ItemIconList.new(self.getObject);
		self.itemList:setLocation(-20, -90, 0);
		self.itemList.pivot = 1;
		self.itemList.scaleVal = 0.8;
		self.itemList.canClick = true;
		self.itemList:setLayout(150, 150, 999);
		self.itemList:setArrayData(reward);
	else
		self.getObject:SetActive(false);
	end

	local config = Lua_RechargeConfigData.getRechargeConfig(self.rechargeId);
	self.btnRecharge.label = LanUtil.formateStr(490000, tonumber(config.money));
	self.btnRecharge:addClickFuntion(self, self.onRechargeClick);

	self:addLuaEvent("UPDATE_GOFISHING_INFO", self, self.updateShowInfo);
	self:updateShowInfo();
end

function Lua_GoFishingPrivilegePanel:dispose()
	self:endTimer();
	if self.desList then
		self.desList:dispose();
		self.desList = nil;
	end
	self:superCall("dispose");
end

function Lua_GoFishingPrivilegePanel:setData(data)
end

function Lua_GoFishingPrivilegePanel:updateShowInfo()
	local endTime = DataCenter.goFishingData.privilegeTime;
	if self.isRechargeClick and endTime > 0 then
		self.isRechargeClick = false;
		OperateAlert.showLangValue(490004);
	end
	
	self.btnRecharge:setEnable(endTime <= 0);
	self.leftTimeText:setEnable(endTime > 0);
	self.stateLabel:setEnable(endTime > 0);
	if endTime > 0 then
		self:startTimer();
		self:onTimer();
	end
end

function Lua_GoFishingPrivilegePanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		Lua_CommonUtil.addTimer("Lua_GoFishingPrivilegePanel", 1, self, self.onTimer);
	end
end

function Lua_GoFishingPrivilegePanel:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		Lua_CommonUtil.removeTimer(self, self.onTimer);
	end
end

function Lua_GoFishingPrivilegePanel:onTimer()
	local endTime = DataCenter.goFishingData.privilegeTime;
	if endTime > 0 then
		self.btnRecharge:setEnable(false);
		self.leftTimeText:setEnable(true);
		self.leftTimeText.text = LanUtil.formateStr(490002, Lua_TimeTransform.transSeconds18(endTime, true, true, true, false));
		self.stateLabel:setEnable(true);
	else
		self.btnRecharge:setEnable(true);
		self.leftTimeText:setEnable(false);
		self.stateLabel:setEnable(false);		
	end
end

function Lua_GoFishingPrivilegePanel:onRechargeClick(go)
	if self.rechargeId > 0 then
		self.isRechargeClick = true;
		DataCenter.sdkInterface:PointOutById(1, self.rechargeId);
	end
end










Lua_GoFishingPrivilegeItem = class("Lua_GoFishingPrivilegeItem", Lua_ListCell)
function Lua_GoFishingPrivilegeItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_GoFishingPrivilegeItem:buildShowItem()
	self:superCall("buildShowItem");

	self.desTxt = UICreate.createLabel(self.content, nil, -285, 0, 100, 31, 24);
	self.desTxt.pivotValue = 3;
	self.desTxt.alignmentValue = 3;
	self.desTxt.horizontalOverflowValue = 1;
	self.desTxt.verticalOverflowValue = 1;
	self.desTxt.colorStr = Lua_ColorDefine.transColor("543A2F");
end

function Lua_GoFishingPrivilegeItem:dispose()
	if self.desTxt then
		self.desTxt:dispose();
		self.desTxt = nil;
	end
	self:superCall("dispose");
end

function Lua_GoFishingPrivilegeItem:setData(data)
	self.desTxt.text = data;
	self.desTxt:resetSize();
	local height = self.desTxt.height - 31;
	self.desTxt:setLocation(-285, height / 4, 0);
end

-- function Lua_GoFishingPrivilegeItem:onPressClick()
-- 	local urlStr = self.desTxt:getUrlByMousePos();
-- 	if not strIsNullOrEmpty(urlStr) then
-- 		local arr = string.split(urlStr, "_");
-- 		if arr and arr:getSize() > 1 then
-- 			DataCenter.packUtil:showItemInfo(tonumber(arr[2]));
-- 		end
-- 	end
-- end