-- 成长投资
Lua_InvestmentPanel = class("Lua_InvestmentPanel", Lua_DisplayObject)
function Lua_InvestmentPanel:ctor(p)
	self:superCall("ctor", p, "InvestmentPanel_skin");
end

function Lua_InvestmentPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.showStep = 1; -- 当前显示阶段

	self.dragList = Lua_DragList.new(self.content, 670, 700 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.dragList.tweenId = 2025;
	self.dragList.delayTween = true;
	self.dragList:setListCell(Lua_InvestmentItem, 670, 125, 1);
	self.dragList:setRectAnchor(1);
	self.dragList:setRectPivot(1);
	self.dragList:setLocation(0, -470, 0);

	self.helpBtn:addClickFuntion(self, self.onHelpClick);
	self.previousIcon:addClickFuntion(self, self.onPreClick);
	self.nextIcon:addClickFuntion(self, self.onNextClick);

	self:addLuaEvent("UPDATE_INVESTMENT_INFO", self, self.updateInvestmentInfo);
	self:updateInvestmentInfo(true);
end

function Lua_InvestmentPanel:setData(actVo)
end

function Lua_InvestmentPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.dragList:setContentRect(670, 700 + adaptHeight);
end

function Lua_InvestmentPanel:updateInvestmentInfo(isFirst)
	local step = isFirst and DataCenter.investmentData.defaultStep or self.showStep;
	self:showInvestmentInfo(step, isFirst);
end

function Lua_InvestmentPanel:showInvestmentInfo(step, immediately)
	if step == nil then
		return;
	end

	self.showStep = step;
	self.moneyNumTxt.text = DataCenter.investmentData:getExtraMoneyByStep(step);

	local arr = DataCenter.investmentData:getShowInfoByStep(step);
	local index;
	local vo;
	for i = 1, arr:getSize() do
		vo = DataCenter.investmentData:getInvestmentVo(arr[i])
		if vo ~= nil then
			if vo.state == 1 or vo.seniorState == 1 then
				index = i;
				break;
			end
		end
	end

	self.dragList:setArrayData(arr);
	if index ~= nil then -- 有奖励可领
		self.dragList:moveToIndex(index, immediately);
	else
		if immediately then
			self.dragList:moveToIndex(1, true);
		end
	end

	if vo ~= nil and vo.isUnlock == 1 then
		self.lockIcon:setEnable(false);
		self.buyBtn:setAltas("common_altas_3", "xui_common_button_027_d");
		self.buyBtn:removeClickFuntion(self, self.onBuyClick);
		self.buyTxt:setLangValue(202200);
	else
		self.lockIcon:setEnable(true);
		self.buyBtn:setAltas("common_altas_3", "xui_common_button_027_n");
		self.buyBtn:addClickFuntion(self, self.onBuyClick);

		local rechargeId = DataCenter.investmentData:getRechargeId(step);
		local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(rechargeId);
		local money = rechargeInfo ~= nil and rechargeInfo.money or 0;
		self.buyTxt.text = LanUtil.formateStr(202201, money);
	end
	self.previousIcon:setEnable(step > 1);
	self.nextIcon:setEnable(step < DataCenter.investmentData.showMaxStep);
end

function Lua_InvestmentPanel:onPreClick()
	if self.showStep - 1 < 1 then
		return;
	end
	self.dragList.showTween = true;
	self:showInvestmentInfo(self.showStep - 1, true);
end

function Lua_InvestmentPanel:onNextClick()
	if self.showStep + 1 > DataCenter.investmentData.showMaxStep then
		return;
	end
	self.dragList.showTween = true;
	self:showInvestmentInfo(self.showStep + 1, true);
end

function Lua_InvestmentPanel:onHelpClick()
	local tipsData = {des = LanUtil.getValue(202202), posX = 27, posY = -320};
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_InvestmentPanel:onBuyClick()
	local rechargeId = DataCenter.investmentData:getRechargeId(self.showStep);
	local rechargeInfo = Lua_RechargeConfigData.getRechargeConfig(rechargeId);
	if rechargeInfo == nil then
		LogManager.LogError(self.showStep .. " step no recharge id：" .. rechargeId, false);
		return;
	end
	DataCenter.sdkInterface:PointOut(1, tonumber(rechargeInfo.money), tonumber(rechargeInfo.money_type),
		tonumber(rechargeInfo.id), rechargeInfo.gift_name, rechargeInfo.gold);
end

function Lua_InvestmentPanel:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	self:superCall("dispose");
end










Lua_InvestmentItem = class("Lua_InvestmentItem", Lua_ListCell)
function Lua_InvestmentItem:ctor(p)
	self:superCall("ctor", p, "InvestmentItem_skin");
end

function Lua_InvestmentItem:buildShowItem()
	self:superCall("buildShowItem");

	self.baseIconList = Lua_ItemIconList.new(self.content);
	self.baseIconList.scaleVal = 0.75;
	self.baseIconList:setLocation(-108, 2);

	self.extraIconList = Lua_ItemIconList.new(self.content);
	self.extraIconList.scaleVal = 0.75;
	self.extraIconList:setLocation(174, 2);
end

function Lua_InvestmentItem:setData(data)
	self._data = DataCenter.investmentData:getInvestmentVo(data);
	if self._data == nil then
		return;
	end

	self.levelTxt.text = LanUtil.formateStr(202206, self._data.level);

	self.baseIconList:setArrayData(self._data.baseVoArr);
	self.baseIconList:setItemDrawMaskState(self._data.state == 2, "investment_atlas", "xui_czjz_label_1");
	for i = 1, self.baseIconList.showArr:getSize() do
		self.baseIconList.showArr[i]:showRedPoint(self._data.state == 1);
	end

	local level = DataCenter.roleData.level;
	self.extraIconList:setArrayData(self._data.extraVoArr);
	self.extraIconList:setItemDrawMaskState(self._data.seniorState == 2, "investment_atlas", "xui_czjz_label_1");
	self.extraIconList:setItemMaskState(self._data.isUnlock ~= 1);
	for i = 1, self.extraIconList.showArr:getSize() do
		self.extraIconList.showArr[i]:showRedPoint(self._data.seniorState ~= 2 and level >= self._data.level);
	end

	if level < self._data.level then
		self.levelBg:setAltas("investment_atlas", "xui_czjz_widget_7");
		self.levelTxt.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
		self.lineBar:setEnable(false);
	else
		self.levelBg:setAltas("investment_atlas", "xui_czjz_widget_6");
		self.levelTxt.colorStr = Lua_ColorDefine.transColorStr("6B3823");
		self.lineBar:setEnable(self._data.nextVo ~= nil);

		local curH = 1;
		local showH = 0;
		if self._data.nextVo ~= nil then
			curH = self._data.nextVo.level - self._data.level;
			showH = level - self._data.level;
			showH = showH > curH and curH or showH;
		end
		self.lineBar:SetDimensions(20, showH / curH * 46);
	end
	self.lineBg:setEnable(self._data.nextVo ~= nil);
end

function Lua_InvestmentItem:onBaseIconClick()
	if self._data.state == 0 then
		OperateAlert.showLangValue(202203);
	elseif self._data.state == 1 then
		Lua_ProxyManager.getProxy("Lua_ExcellentActivityProxy"):sInvestmentDraw(self._data.id);
	else
		OperateAlert.showLangValue(202204);
	end
end

function Lua_InvestmentItem:onExtraIconClick()
	if self._data.seniorState == 0 then
		OperateAlert.showLangValue(202205);
	elseif self._data.seniorState == 1 then
		Lua_ProxyManager.getProxy("Lua_ExcellentActivityProxy"):sInvestmentDraw(self._data.id);
	else
		OperateAlert.showLangValue(202204);
	end
end

function Lua_InvestmentItem:onPressClick()
	if self.pressItem == nil then
		return;
	end
	if self.clickType == 1 then
		self:onBaseIconClick();
	else
		self:onExtraIconClick();
	end
end

function Lua_InvestmentItem:onMouseDownHandle()
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.71, 0.71);
	end
end

function Lua_InvestmentItem:onMouseUpHandle()
	if self.pressItem ~= nil then
		self.pressItem:setScale(0.75, 0.75);
	end
end

function Lua_InvestmentItem:checkClick()
	local winPosB = LuaUtil.getTouchPosInverseObj(self.baseIconList.mainContent);
	for i = 1, self.baseIconList.showArr:getSize() do
		if self.baseIconList.showArr[i].isActive and self.baseIconList.showArr[i]:checkInBound(winPosB.x, winPosB.y) then
			self.clickType = 1;
			return self.baseIconList.showArr[i];
		end
	end

	local winPosE = LuaUtil.getTouchPosInverseObj(self.extraIconList.mainContent);
	for i = 1, self.extraIconList.showArr:getSize() do
		if self.extraIconList.showArr[i].isActive and self.extraIconList.showArr[i]:checkInBound(winPosE.x, winPosE.y) then
			self.clickType = 2;
			return self.extraIconList.showArr[i];
		end
	end
	return nil;
end

function Lua_InvestmentItem:dispose()
	if self.baseIconList ~= nil then
		self.baseIconList:dispose();
		self.baseIconList = nil;
	end
	if self.extraIconList ~= nil then
		self.extraIconList:dispose();
		self.extraIconList = nil;
	end
	self.pressItem = nil;
	self._data = nil;
	self:superCall("dispose");
end