-- 英雄挑战任务界面
Lua_HeroChallengeTaskWindow = class("Lua_HeroChallengeTaskWindow", Lua_Window);
function Lua_HeroChallengeTaskWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_HeroChallengeTaskWindow";
	self.skinName = "HeroChallengeTaskWindow_skin";
	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.showClose = true;
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_HeroChallengeTaskWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.showImg:setUrl(DataCenter.heroChallengeData.taskUrl);

	self.taskList = Lua_DragList.new(self.content, 628, 700, Lua_AxisDefine.Vertical);
	-- self.taskList.tweenId = 2023;
	self.taskList:setListCell(Lua_HeroChallengeTaskItem, 628, 143, 1);
	self.taskList:setCellSpacing(0, 4);
	self.taskList:setLocation(0, -141, 0);

	self:addLuaEvent("UPDATE_HEROCHALLENGE_TASK_INFO", self, self.updateHeroChallengeTaskInfo);
	Lua_ProxyManager.getProxy("Lua_OpenServerTrialProxy"):sHeroChallengeTaskInfo();
end

function Lua_HeroChallengeTaskWindow:updateHeroChallengeTaskInfo(msg)
	if msg == nil then
		return;
	end

	-- 可领取＞未达成＞已领取，flag：0未完成 1可领取 2已领取
	table.sort( msg,
		function(a, b)
			if a.flag == b.flag then
				return a.id < b.id;
			else
				local aWeight = (a.flag + 1) % 3;
				local bWeight = (b.flag + 1) % 3;
				return aWeight > bWeight;
			end
		end
	);
	self.taskList:setArrayData(msg);
	self.taskList:moveToIndex(1, true, false);
end

function Lua_HeroChallengeTaskWindow:dispose()
	if self.taskList ~= nil then
		self.taskList:dispose();
		self.taskList = nil;
	end
	self:superCall("dispose");
end










Lua_HeroChallengeTaskItem = class("Lua_HeroChallengeTaskItem", Lua_ListCell);
function Lua_HeroChallengeTaskItem:ctor(p)
	self:superCall("ctor", p, "HeroChallengeTaskItem_skin");
end

function Lua_HeroChallengeTaskItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 360, 87, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_HeroChallengeTaskRewardItem, 87, 87, 1);
	self.rewardList:setCellSpacing(9, 0);
	self.rewardList:setRectPivot(3);
	self.rewardList:setLocation(-280, -16, 0);
	self:setSubList(self.rewardList);

	self.stateBtn:addClickFuntion(self, self.onDrawRewardClick);
end

function Lua_HeroChallengeTaskItem:setData(data)
	self._data = data;
	if self._data == nil then
		return;
	end

	local configData = getConfig("hero_challenge", data.id);
	self.titleTxt.text = configData.des;
	self.rewardList.canDrag = #configData.task_award > 3;
	self.rewardList:setArrayData(configData.task_award);

	self.progressBar:setMaxValue(configData.process);
	self.progressBar:setValue(data.progress);
	self.progressBar:setText(data.progress .. "/" .. configData.process);

	if data.flag == 0 then
		self.stateBtn:setLangValue(680021);
		self.stateBtn:setStyle(16);
	elseif data.flag == 1 then
		self.stateBtn:setLangValue(680022);
		self.stateBtn:setStyle(1);
	end
	-- self.progressBar:setEnable(data.flag ~= 2);
	self.progressBar:setEnable(false);
	self.stateBtn:setEnable(data.flag ~= 2);
	self.drawedIcon:setEnable(data.flag == 2);
end

function Lua_HeroChallengeTaskItem:onDrawRewardClick(go)
	if self._data.flag == 0 then
		Lua_MsgUtil.callFunc("REQUEST_HEROCHALLENGE_CHALLENGE_INFO");
		Lua_WindowUtil.openWin("Lua_HeroChallengeTaskWindow", Lua_WinParam.ACTION_CLOSE);
	else
		Lua_ProxyManager.getProxy("Lua_OpenServerTrialProxy"):sHeroChallengeDrawTaskReward(self._data.id);
	end
end

function Lua_HeroChallengeTaskItem:dispose()
	self._data = nil;
	self:superCall("dispose");
end










Lua_HeroChallengeTaskRewardItem = class("Lua_HeroChallengeTaskRewardItem", Lua_ItemIconCell);
function Lua_HeroChallengeTaskRewardItem:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.7, 0.7);
end