Lua_RechargePanel = class("Lua_RechargePanel", Lua_DisplayObject);
function Lua_RechargePanel:ctor(p)
	self:superCall("ctor", p, "RechargePanel_skin");
end

function Lua_RechargePanel:buildShowItem()
	self:superCall("buildShowItem");

	self.infoBg:SetDimensions(695, 874 + self.adaptHeight);

	self.dragList = Lua_DragList.new(self.content, 675, 754 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.dragList:setListCell(Lua_RechargeItem, 225, 304, 3);
	self.dragList:setCellSpacing(0, 7);
	self.dragList:setLocation(0, -64, 0);
	self.dragList.tweenId = 2016;

	self:addLuaEvent("SET_VIPPANEL_INFO", self, self.updateVipInfo);
	self:addLuaEvent("SET_RECHARGEPANEL_INFO", self, self.updateRechargeInfo);
	Lua_ProxyManager.getProxy("Lua_VipProxy"):sGetVipPanelInfo();
	Lua_ProxyManager.getProxy("Lua_RechargeProxy"):sRechargeInfo();
end

function Lua_RechargePanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.infoBg:SetDimensions(695, 874 + adaptHeight);
	self.dragList:setContentRect(675, 754 + adaptHeight);
	self.dragList:moveToIndex(1);
end

function Lua_RechargePanel:updateRechargeInfo()
	self.dragList:setArrayData(DataCenter.rechargeData.rechargeShowList);
	Lua_ProxyManager.getProxy("Lua_VipProxy"):sGetVipPanelInfo();
end

function Lua_RechargePanel:updateVipInfo()
	local nextVipVo;
	if DataCenter.vipData.level >= DataCenter.vipData.maxVipLevel then
		nextVipVo = DataCenter.vipData:getVipVoByLevel(DataCenter.vipData.maxVipLevel);
		self.tipTxt:setEnable(false);
	else
		nextVipVo = DataCenter.vipData:getVipVoByLevel(DataCenter.vipData.level + 1);
		local icon = DataCenter.vipData:getExpIconData();
		local str = spliceIconStr(icon.atlas, icon.sprite, 27, 33);
		local val = nextVipVo.target - DataCenter.vipData.vipExp;
		self.tipTxt.text = LanUtil.formateStr(320010, str, val, nextVipVo.id);
		self.tipTxt:setEnable(true);
	end

	self.vipNumTxt.text = DataCenter.vipData.level;
	self.bar:setMaxValue(nextVipVo.target);
	self.bar:setValue(DataCenter.vipData.vipExp);

	if DataCenter.vipData.level >= DataCenter.vipData.maxVipLevel and DataCenter.vipData.vipExp >= nextVipVo.target then
		self.bar:setText(nextVipVo.target .. "/" .. nextVipVo.target);
	else
		self.bar:setText((DataCenter.vipData.vipExp) .. "/" .. nextVipVo.target);
	end
end

function Lua_RechargePanel:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	self:superCall("dispose");
end










Lua_RechargeItem = class("Lua_RechargeItem", Lua_ListCell);
function Lua_RechargeItem:ctor(p)
	self:superCall("ctor", p, "RechargeItem_skin");
end

function Lua_RechargeItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_RechargeItem:setData(data)
	self._data = data;

	self.costNumTxt.text = LanUtil.formateStr(320011, data.money);
	self.getNumTxt.text = data.gold;
	self.getNumTxt:resetSize();

	local oldWidth = 37;
	self.getIcon:setLocation(0 - (self.getNumTxt.width - oldWidth) / 2, -72);
	self.getNumTxt:setLocation(0 - (self.getNumTxt.width - oldWidth) / 2, -74);

	local rechargeItem = Lua_RechargeConfigData.getRechargeConfig(tonumber(self._data.recharge_id));
	if rechargeItem ~= nil and rechargeItem.recharge_altas ~= nil and rechargeItem.recharge_icon ~= nil then
		self.itemSp:setAltas(rechargeItem.recharge_altas, rechargeItem.recharge_icon);
		self.itemSp:resetSize();
	end

	if data.rebate ~= nil and data.rebate > 0 and data.first_flag ~= nil and data.first_flag == 1 then
		self.firstReacherTxt:setEnable(true);
		self.tipsBg:setEnable(true);
		self.minGetNumTxt:setEnable(true);
		self.minGetIcon:setEnable(true);
		self.minGetNumTxt.text = data.rebate;
	else
		self.firstReacherTxt:setEnable(false);
		self.tipsBg:setEnable(false);
		self.minGetIcon:setEnable(false);
		self.minGetNumTxt:setEnable(false);
	end
end

function Lua_RechargeItem:onPressClick(go)
    DataCenter.sdkInterface:PointOut(tonumber(self._data.gold), tonumber(self._data.money),
    	tonumber(self._data.money_type), tonumber(self._data.recharge_id), self._data.gift_name, self._data.gold);
end

function Lua_RechargeItem:dispose(go)
	self._data = nil;
	self:superCall("dispose");
end