-- 资源找回
Lua_RecoverResourcesPanel = class("Lua_RecoverResourcesPanel", Lua_DisplayObject);
function Lua_RecoverResourcesPanel:ctor(p)
	self:superCall("ctor", p, "RecoverResourcesPanel_skin");
end

function Lua_RecoverResourcesPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.dragContainer = Lua_DragContainer.new(self.content, 662, 690 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.dragContainer.tweenId = 2002;
	self.dragContainer:setCellSpacing(0, 10);
	self.dragContainer:setLocation(0, -50);

	self.ruleBtn:addClickFuntion(self, self.onRuleClick);
	self.recoverBtn:addClickFuntion(self, self.onRecoverClick);

	self:addLuaEvent("UPDATE_RECOVERRESOURCES_INFO", self, self.updateRecoverResourcesInfo);
	self:addLuaEvent("UPDATE_RECOVERRESOURCES_DRAW_INFO", self, self.updateRecoverResourcesDrawInfo);
	Lua_ProxyManager.getProxy("Lua_ExcellentActivityProxy"):sRecoverResourcesInfo();
end

function Lua_RecoverResourcesPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.dragContainer:setContentRect(662, 690 + adaptHeight);
end

function Lua_RecoverResourcesPanel:setData(actVo)
end

function Lua_RecoverResourcesPanel:updateRecoverResourcesInfo()
	local recoverResourcesData = DataCenter.recoverResourcesData;
	self.desTxt_2.text = LanUtil.formateStr("{1}%", recoverResourcesData.multiple * 100);
	
	local arr = recoverResourcesData.recoverResourcesArr;
	self.dragContainer:clearList();
	for i = 1, arr:getSize() do
		self.dragContainer:addSubContainer(Lua_RecoverResourcesItemm, arr[i]);
	end
	self.dragContainer:updateChildPos();

	self:updateRecoverResourcesDrawInfo();
end

function Lua_RecoverResourcesPanel:updateRecoverResourcesDrawInfo()
	local isRecovered = DataCenter.recoverResourcesData.isRecovered
	local langId = isRecovered and 767000 or 767001;
	self.recoverBtn:setLangValue(langId);
	self.recoverBtn:setStyle(isRecovered and 23 or 20);
	self:showRedDot(not isRecovered);
end

function Lua_RecoverResourcesPanel:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.recoverBtn.mainContent);
			self.redPoint:createRedPointEff();
			self.redPoint:setLocation(133, 21.5, 0);
			self.redPoint:setScale(1.3, 1.3, 1.3);
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_RecoverResourcesPanel:onRuleClick(go)
	local tipsData = { des = LanUtil.getValue(767002), posX = 175, posY = -260 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_RecoverResourcesPanel:onRecoverClick(go)
	if self.checkItem and getTime() - self.checkItem < 0.5 then
		OperateAlert.showLangValue(767005);
		return
	end
	self.checkItem = getTime();

	if DataCenter.recoverResourcesData.isRecovered then
		OperateAlert.showLangValue(767003);
	else
		Lua_ProxyManager.getProxy("Lua_ExcellentActivityProxy"):sDrawRecoverResourcesReward();
	end
end

function Lua_RecoverResourcesPanel:dispose()
	if self.dragContainer ~= nil then
		self.dragContainer:dispose();
		self.dragContainer = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self:superCall("dispose");
end










Lua_RecoverResourcesItemm = class("Lua_RecoverResourcesItemm", Lua_DragContainerItem);
function Lua_RecoverResourcesItemm:ctor(p)
	self:superCall("ctor", p, "RecoverResourcesItem_skin");
end

function Lua_RecoverResourcesItemm:buildShowItem()
	self:superCall("buildShowItem");

	self.offsetHeight = 71;
	self.defaultHeight = 104;

	self.rewardList = Lua_DragList.new(self.content, 576, 112, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_RecoverResourcesRewardItemm, 112, 112, 1);
	self.rewardList:setCellSpacing(12, 0);
	self.rewardList:setRectPivot(3);
	self.rewardList:setLocation(-288, -12, 0);
	self:setSubList(self.rewardList);

	self:addLuaEvent("UPDATE_RECOVERRESOURCES_DRAW_INFO", self, self.updateShowInfo);
end

function Lua_RecoverResourcesItemm:setData(data)
	self._data = DataCenter.recoverResourcesData:getShowInfoVo(data);
	if self._data == nil then
		return;
	end

	local info = DataCenter.recoverResourcesData:getRecoverResourcesVo(self._data[1]);
	self.titleTxt.text = info.name;
	self:updateShowInfo();

	if info.resourceType == 1 then
		local arr = self:getMergeRewardInfo();
		self.rewardList.canDrag = arr:getSize() > 4;
		self.rewardList:setArrayData(arr);
		self.rewardList:moveToIndex(1, true, false);
		self.rewardList:setEnable(true);
		self.desObj:SetActive(false);
	elseif info.resourceType == 2 then
		self.rewardList:setEnable(false);
		self.desObj:SetActive(true);
		self:getMergeDesInfo();
	else
		self.rewardList:setEnable(false);
		self.desObj:SetActive(false);
	end

	local offsetH = info.resourceType == 1 and self.offsetHeight or (self._data:getSize() - 1) * 52 + 25;
	self.itemBg:SetDimensions(662, self.defaultHeight + offsetH);
	self.titleBg:setLocation(-240, 30 + offsetH / 2, 0);
	self.titleTxt:setLocation(-312, 31.5 + offsetH / 2, 0);
	self.dayTxt:setLocation(309, 31.5 + offsetH / 2, 0);
	LuaUtil.setObjPos(self.desObj, 0, -27 + offsetH / 2, 0);
end

function Lua_RecoverResourcesItemm:getMergeRewardInfo()
	local obj;
	local tvoInfo;
	local sortWeight = 1;
	local itemDic = {};
	for i = 1, self._data:getSize() do
		local vo = DataCenter.recoverResourcesData:getRecoverResourcesVo(self._data[i]);
		for j = 1, #vo.recoverReward do
			obj = vo.recoverReward[j];
			tvoInfo = itemDic[obj.key];
			if tvoInfo == nil then
				tvoInfo = {id = obj.key, amount = obj.value, sortWeight = sortWeight};
				sortWeight = sortWeight + 1;
				itemDic[obj.key] = tvoInfo;
			else
				tvoInfo.amount = tvoInfo.amount + obj.value;
			end
		end
	end
	local arr = Array();
	for k,v in pairs(itemDic) do
		arr:add(v);
	end
	arr:sort("sortWeight", false);
	return arr;
end

function Lua_RecoverResourcesItemm:getMergeDesInfo()
	if self.desItemArr == nil then
		self.desItemArr = Array();
	end

	local arrLen = self.desItemArr:getSize();
	local dataLen = self._data:getSize();
	local maxLen = dataLen >= arrLen and dataLen or arrLen;
	local item;
	for i = 1, maxLen do
		item = self.desItemArr[i];
		if i > dataLen then
			item:setEnable(false);
		else
			if item == nil then
				item = Lua_RecoverResourcesDesItem.new(self.desObj);
				self.desItemArr:add(item);
			end
			item:setEnable(true);
			item:setData(self._data[i]);
			item:setLocation(0, -52 * (i - 1), 0);
		end
	end
end

function Lua_RecoverResourcesItemm:updateShowInfo()
	local isRecovered = DataCenter.recoverResourcesData.isRecovered;
	local colorStr = isRecovered and "ED4C30" or "479154";
	local vo;
	local maxDay = 0;
	for i = 1, self._data:getSize() do
		vo = DataCenter.recoverResourcesData:getRecoverResourcesVo(self._data[i]);
		if vo.recoverDays > maxDay then
			maxDay = vo.recoverDays;
		end
	end
	self.dayTxt.text = LanUtil.formateStr(767004, colorStr, maxDay);
end

function Lua_RecoverResourcesItemm:getWidth()
	return self.itemBg.width;
end

function Lua_RecoverResourcesItemm:getHeight()
	return self.itemBg.height;
end

function Lua_RecoverResourcesItemm:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.desItemArr ~= nil then
		self.desItemArr:dispose();
		self.desItemArr = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end










Lua_RecoverResourcesRewardItemm = class("Lua_RecoverResourcesRewardItemm", Lua_ItemIconCell);
function Lua_RecoverResourcesRewardItemm:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.9, 0.9);
end










Lua_RecoverResourcesDesItem = class("Lua_RecoverResourcesDesItem", Lua_DisplayObject);
function Lua_RecoverResourcesDesItem:ctor(p)
	self:superCall("ctor", p, "RecoverResourcesDesItem_skin");
end

function Lua_RecoverResourcesDesItem:setData(data)
	local vo = DataCenter.recoverResourcesData:getRecoverResourcesVo(data);
	self.desTxt.text = vo.des;
	self.timesTxt.text = "+" .. vo.times * vo.recoverDays;
end