Lua_SignInPanel = class("Lua_SignInPanel", Lua_DisplayObject);
function Lua_SignInPanel:ctor(p)
	self:superCall("ctor", p, "SignInPanel_skin");
end

function Lua_SignInPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.bg_1:SetDimensions(708, 845 + self.adaptHeight);
	self.bg_2:SetDimensions(704, 745 + self.adaptHeight);

	self.itemList = Lua_DragList.new(self.content, 670, 628 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -54, 0);
	self.itemList.tweenId = 2003;
	self.itemList.delayTween = true;
	self.itemList:setListCell(Lua_SignInItem, 127, 153, 5);
	self.itemList:setCellSpacing(9, 10);

	self.redPointIcon = Lua_RedPointIcon.new(self.btnObject, Lua_RedPointList.Welfare_SignIn);
	self.redPointIcon:setLocation(100, 16);

	self.btnSingIn:addClickFuntion(self, self.onSingInClick);

	self:addLuaEvent("UPDATE_SIGNIN_INFO", self, self.updateSingInInfo);
	Lua_ProxyManager.getProxy("Lua_WelfareProxy"):sSignInInfo();
end

function Lua_SignInPanel:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.redPointIcon ~= nil then
		self.redPointIcon:dispose();
		self.redPointIcon = nil;
	end
	self:superCall("dispose");
end

function Lua_SignInPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.bg_1:SetDimensions(708, 845 + adaptHeight);
	self.bg_2:SetDimensions(704, 745 + adaptHeight);
	self.itemList:setContentRect(670, 628 + adaptHeight);
end

function Lua_SignInPanel:setData(data)

end

function Lua_SignInPanel:onSingInClick(go)
	if DataCenter.welfareData.sign == 1 and DataCenter.welfareData.repair == 0 then
		local tipData = {
			des = LanUtil.getValue(128024), btnType = 1, sureLabel = LanUtil.getValue(128025), 
			owner = self, sureFun = self.gotoRecharge
		};
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
		return;
	end 
	Lua_ProxyManager.getProxy("Lua_WelfareProxy"):sSignIn(DataCenter.welfareData.day + 1);
end

function Lua_SignInPanel:gotoRecharge()
	DataCenter.funcPathUtil:gotoFunction(1024)
end

function Lua_SignInPanel:updateSingInInfo()
	local data = DataCenter.welfareData;
	local arr = DataCenter.welfareUtil:getSignInfoByRound(data.round, data.totalDay);

	self.singInText.text = LanUtil.formateStr(128020, tostring(data.day), tostring(data.totalDay), tostring(data.leftDay));
	self.itemList:setArrayData(arr);
	self.itemList:moveToIndex(data.day, true, false);

	if data.sign == 0 then
		self.btnSingIn:setMouseEnable(true);
		self.btnSingIn:setStyle(5);
		self.btnSingIn:setLangValue(128021);
	else
		if data.repair == 2 then
			self.btnSingIn:setMouseEnable(false);
			self.btnSingIn:setStyle(7);
			self.btnSingIn:setLangValue(128023);
		else
			self.btnSingIn:setMouseEnable(true);
			self.btnSingIn:setStyle(5);
			self.btnSingIn:setLangValue(128022);
		end
	end
end




















Lua_SignInItem = class("Lua_SignInItem", Lua_ListCell);
function Lua_SignInItem:ctor(p)
	self:superCall("ctor", p, "SignInItem_skin");
end

function Lua_SignInItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_SignInItem:dispose()
	self:superCall("dispose");
end

function Lua_SignInItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
		
	if data.signInType == 1 then -- 已签到
		self.mask:setEnable(true);
		self.sign:setEnable(true);
		self.repairIcon:setEnable(false);
		self.bg:setAltas("sign_in_altas_1", "ui_mrqd_window_002");
		self.bg:SetDimensions(127, 153);
	elseif data.signInType == 2 then -- 当天可签到
		self.mask:setEnable(false);
		self.sign:setEnable(false);
		self.repairIcon:setEnable(false);
		self.bg:setAltas("sign_in_altas_1", "ui_mrqd_window_003");
		self.bg:SetDimensions(133, 158);
	elseif data.signInType == 3 then -- 当天可再次领取
		self.mask:setEnable(true);
		self.sign:setEnable(false);
		self.repairIcon:setEnable(true);
		self.bg:setAltas("sign_in_altas_1", "ui_mrqd_window_003");
		self.bg:SetDimensions(133, 158);
	elseif data.signInType == 4 then -- 当天已签到不可再次领取
		self.mask:setEnable(true);
		self.sign:setEnable(true);
		self.repairIcon:setEnable(false);
		self.bg:setAltas("sign_in_altas_1", "ui_mrqd_window_002");
		self.bg:SetDimensions(127, 153);
	elseif data.signInType == 5 then -- 未到
		self.mask:setEnable(false);
		self.sign:setEnable(false);
		self.repairIcon:setEnable(false);
		self.bg:setAltas("sign_in_altas_1", "ui_mrqd_window_002");
		self.bg:SetDimensions(127, 153);
	end

	if data.signInType == 2 or data.signInType == 3 then
		self.day.effectColorStr = Lua_ColorDefine.transColor("C28017");
	else
		self.day.effectColorStr = Lua_ColorDefine.transColor("403334");
	end
	self.day.text = LanUtil.formateStr(128026, tostring(data.day));
	self.itemIcon:setAltas(data.itemVo.atlas, data.itemVo.sprite);
	if data.itemVo.count > 0 then
		self.itemCount.text = data.itemVo.count;
	else
		self.itemCount.text = "";
	end
end

function Lua_SignInItem:onPressClick()
	if self.data == nil then
		return;
	end

	if self.data.signInType == 2 then
		Lua_ProxyManager.getProxy("Lua_WelfareProxy"):sSignIn(DataCenter.welfareData.day + 1);
	elseif self.data.signInType == 3 then
		if DataCenter.welfareData.sign == 1 and DataCenter.welfareData.repair == 0 then
			local tipData = {
				des = LanUtil.getValue(128024), btnType = 1, sureLabel = LanUtil.getValue(128025),
				owner = self, sureFun = self.gotoRecharge
			};
		    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
		else
			Lua_ProxyManager.getProxy("Lua_WelfareProxy"):sSignIn(DataCenter.welfareData.day + 1);
		end 
	else
		DataCenter.packUtil:showItemInfo(self.data.itemVo);
	end
end

-- 去充值
function Lua_SignInItem:gotoRecharge()
	DataCenter.funcPathUtil:gotoFunction(1024)
end