-- 星河试炼
Lua_StarRiverTrialPanel = class("Lua_StarRiverTrialPanel", Lua_DisplayObject);
function Lua_StarRiverTrialPanel:ctor(p)
	self:superCall("ctor", p, "StarRiverTrialPanel_skin");
end

function Lua_StarRiverTrialPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rankRewardList = Lua_DragList.new(self.topObj, 294, 82, Lua_AxisDefine.Horizontal);
	self.rankRewardList:setListCell(Lua_StarRiverTrialRankRewardSubItem, 82, 82, 1);
	self.rankRewardList:setCellSpacing(8, 0);
	self.rankRewardList:setLocation(45, 316, 0);
	self.rankRewardList:setRectAnchor(1);
	self.rankRewardList:setRectPivot(3);

	self.rewardList = Lua_DragList.new(self.content, 680, 750  + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.rewardList:setListCell(Lua_StarRiverTrialItem, 680, 190, 1);
	self.rewardList:setLocation(0, -145, 0);
	self.rewardList.tweenId = 2014;

	self.infoBg:SetDimensions(704, 794 + self.adaptHeight);

	self.tipsBtn:addClickFuntion(self, self.onShowTipsClick);
	self.checkRankImg:addClickFuntion(self, self.onReadRankClick);

	self:addLuaEvent("UPDATE_STARRIVERTRIAL_INFO", self, self.updateStarRiverTrialInfo);
	Lua_ProxyManager.getProxy("Lua_LimitedTimeActivityProxy"):sStarRiverTrialInfo(1);
end

function Lua_StarRiverTrialPanel:setData(data)
end

function Lua_StarRiverTrialPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	
	self.rewardList:setContentRect(680, 750 + adaptHeight);
	self.infoBg:SetDimensions(704, 794 + adaptHeight);
end

function Lua_StarRiverTrialPanel:updateStarRiverTrialInfo()
	local data = DataCenter.starRiverTrialData;
	self.curStarTxt.text = LanUtil.formateStr(510000, data.total_star);

	local rankStr;
	if data.curr_rank == 0 then
		rankStr = LanUtil.getValue(510001);
	else
		rankStr = data.curr_rank;
	end
	self.curRankTxt.text = LanUtil.formateStr(510002, rankStr);
    
	local rank = data.curr_rank;
	local config = data:getRankRewardConfig(rank);
	local len = 0;
	if config ~= nil and config.rank_reward ~= nil then
		len = #config.rank_reward;
		self.rankRewardList.canDrag = len > 3;
	    self.rankRewardList:setArrayData(config.rank_reward);
	end
	self.noRewardTxt:setEnable(len == 0);

	table.sort(data.rewardVoList, 
		function(a, b)
			if a.sort > b.sort then
				return false;
			else
				if a.sort == b.sort then
					return a.id < b.id;
				end
				return true;
			end
		end);
	self.rewardList:setArrayData(data.rewardVoList);

	self:startTimer();
	self:updateLeftTime();
end

function Lua_StarRiverTrialPanel:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("Lua_StarRiverTrialPanel", 1, self, self.updateLeftTime);
	end
end

function Lua_StarRiverTrialPanel:updateLeftTime()
	local remainTime = DataCenter.starRiverTrialData.close_tick - DataCenter.roleData.serverTime;
	if remainTime <= 0 then
		self.leftTimeTxt:setLangValue(510003);
		self.tipsTxt:setLangValue(510004);
		self:endTimer();
		return;
	end
	self.leftTimeTxt.text = LanUtil.formateStr(510005, Lua_TimeTransform.transSeconds18(remainTime, true, true, true, false));
    self.tipsTxt:setLangValue(510006);
end

function Lua_StarRiverTrialPanel:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

function Lua_StarRiverTrialPanel:onShowTipsClick(go)
	local tipsData = {posX = 191, posY = -232, des = LanUtil.getValue(510007)};
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_StarRiverTrialPanel:onReadRankClick(go)
	Lua_WindowUtil.openWin("Lua_StarRiverTrialRankWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_StarRiverTrialPanel:dispose()
	if self.rankRewardList ~= nil then
		self.rankRewardList:dispose();
		self.rankRewardList = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self:endTimer();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_StarRiverTrialItem = class("Lua_StarRiverTrialItem", Lua_ListCell)
function Lua_StarRiverTrialItem:ctor(p)
	self:superCall("ctor", p, "StarRiverTrialItem_skin");
end

function Lua_StarRiverTrialItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 420, 93, Lua_AxisDefine.Horizontal);
	self.itemList:setListCell(Lua_StarRiverTrialSubItem, 93, 93, 1);
	self.itemList:setLocation(-300, -12, 0);
	self.itemList:setRectPivot(3);
	self.itemList:setCellSpacing(8, 0);
	self:setSubList(self.itemList);

	self.stateBtn:addClickFuntion(self, self.onBtnClick);
end

function Lua_StarRiverTrialItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.tipsTxt.text = LanUtil.formateStr(510008, data.star_amount);

	self.itemList.canDrag = #data.reward > 3;
	self.itemList:setArrayData(data.reward);

	local actTime = DataCenter.starRiverTrialData.close_tick - DataCenter.roleData.serverTime;
	if actTime > 0 then
		if data.state == 2 then
			self.stateBtn:setEnable(false);
			self.stateImg:setEnable(true);
			self.stateImg:setAltas("common_altas_1", "xui_common_label_12");
		else
			self.stateImg:setEnable(false);
			self.stateBtn:setEnable(true);
			if data.state == 1 then
				self.stateBtn.label = LanUtil.getValue(510009);
				self.stateBtn:setStyle(5);
			else
				self.stateBtn.label = LanUtil.getValue(510010);
				self.stateBtn:setStyle(16);
			end
		end
	else
		self.stateBtn:setEnable(false);
		self.stateImg:setEnable(true);
		if data.state ~= 0 then
			self.stateImg:setAltas("starRiver_atlas", "xui_xhsl_label_1");
		else
			self.stateImg:setAltas("starRiver_atlas", "xui_xhsl_label_2");
		end
	end

	self:showRedDot(actTime > 0 and data.state == 1);
end

function Lua_StarRiverTrialItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(295, 5, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_StarRiverTrialItem:onBtnClick(go)
	if self.data.state == 1 then
		Lua_ProxyManager.getProxy("Lua_LimitedTimeActivityProxy"):sDrawStarRiverTialReward(self.data.id);
	else
		DataCenter.funcPathUtil:gotoFunction(DataCenter.starRiverTrialData.constConfig.event_id, true)
	end
end

function Lua_StarRiverTrialItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.itemList.sub);
	for i = 1, self.itemList.showList:getSize() do
		if self.itemList.showList[i]:checkInBound(winPos.x, winPos.y) then
			return self.itemList.showList[i];
		end
	end
	return nil;
end

function Lua_StarRiverTrialItem:onMouseDownHandle()
	if #self.data.reward > 3 then
		return;
	end
	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:onMouseDownHandle();
	end
end

function Lua_StarRiverTrialItem:onMouseUpHandle()
	if #self.data.reward > 3 then
		return;
	end
	if self.pressItem ~= nil then
		self.pressItem:onMouseUpHandle();
	end
end

function Lua_StarRiverTrialItem:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.pressItem ~= nil then
		self.pressItem:dispose();
		self.pressItem = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end










Lua_StarRiverTrialRankRewardSubItem = class("Lua_StarRiverTrialRankRewardSubItem", Lua_ItemIconCell)
function Lua_StarRiverTrialRankRewardSubItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_StarRiverTrialRankRewardSubItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon:setScale(0.66, 0.66);
end

function Lua_StarRiverTrialRankRewardSubItem:onMouseDownHandle()
	self.itemIcon:setScale(0.627, 0.627);
end

function Lua_StarRiverTrialRankRewardSubItem:onMouseUpHandle()
	self.itemIcon:setScale(0.66, 0.66);
end










Lua_StarRiverTrialSubItem = class("Lua_StarRiverTrialSubItem", Lua_ListCell)
function Lua_StarRiverTrialSubItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_StarRiverTrialSubItem:buildShowItem()
	self:superCall("buildShowItem");
    
    self.itemIcon = Lua_ItemIcon.new(self.content);
end

function Lua_StarRiverTrialSubItem:setData(data)
	self:superCall("setData", data);

	if self.tvo == nil then
		self.tvo = Lua_ToolVo.createToolVo(data[1], data[2]);
	else
		self.tvo:setData(data[1], data[2]);
	end
	self.itemIcon:setData(self.tvo);
	self.itemIcon:setScale(0.75, 0.75);
end

function Lua_StarRiverTrialSubItem:onMouseDownHandle()
	self.itemIcon:setScale(0.71, 0.71);
end

function Lua_StarRiverTrialSubItem:onMouseUpHandle()
	self.itemIcon:setScale(0.75, 0.75);
end

function Lua_StarRiverTrialSubItem:onPressClick()
	self.itemIcon:onItemClick();
end

function Lua_StarRiverTrialSubItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.tvo = nil;

	self:superCall("dispose");
end