-- 星河试炼排行奖励
Lua_StarRiverTrialRankRewardWindow = class("Lua_StarRiverTrialRankRewardWindow", Lua_Window);
function Lua_StarRiverTrialRankRewardWindow:ctor(p)
	self:superCall("ctor");

	self.windowName = "Lua_StarRiverTrialRankRewardWindow";
	self.skinName = "StarRiverTrialRankRewardWindow_skin";
	self.showBlackMask = true;
	self.closeClickMask = true;
end

function Lua_StarRiverTrialRankRewardWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 651, 570, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_StarRiverTrialRewardItem, 651, 120, 1);
	self.itemList:setLocation(0, -52, 0);
	self.itemList:setCellSpacing(0, 5);

	self.myRewardList = Lua_DragList.new(self.content, 320, 87, Lua_AxisDefine.Horizontal);
	self.myRewardList:setListCell(Lua_StarRiverTrialIconItem, 87, 87, 1);
	self.myRewardList:setCellSpacing(5, 0);
	self.myRewardList:setLocation(51, -413);

	self:updateShowInfo();
end

function Lua_StarRiverTrialRankRewardWindow:updateShowInfo()
	local rank = DataCenter.starRiverTrialData.curr_rank;
	if rank > DataCenter.starRiverTrialData.constConfig.show_rank_limit then
		self.myRankTxt.text = DataCenter.starRiverTrialData.constConfig.show_rank_limit.."+";
		self.myRankTxt.fontSize = 50;
	elseif rank == 0 then
		self.myRankTxt:setLangValue(510014);
		self.myRankTxt.fontSize = 26;
	else
		self.myRankTxt.text = rank;
		self.myRankTxt.fontSize = 50;
	end

	local config = DataCenter.starRiverTrialData:getRankRewardConfig(rank);
	if config ~= nil and config.rank_reward ~= nil then
		local len = #config.rank_reward;
		self.myRewardList:setArrayData(config.rank_reward);
	    self.myRewardList.canDrag = len > 3;
	end
    
	self.itemList:setArrayData(DataCenter.starRiverTrialData.rankRewardConfig);

	if DataCenter.starRiverTrialData.close_tick - DataCenter.roleData.serverTime <= 0 then
		self.tipTxt:setLangValue(510004);
	else
		self.tipTxt:setLangValue(510006);
	end
end

function Lua_StarRiverTrialRankRewardWindow:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end

	if self.myRewardList ~= nil then
		self.myRewardList:dispose();
		self.myRewardList = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_StarRiverTrialRewardItem = class("Lua_StarRiverTrialRewardItem", Lua_ListCell);
function Lua_StarRiverTrialRewardItem:ctor(p)
	self:superCall("ctor", p, "StarRiverTrialRewardItem_skin");
end

function Lua_StarRiverTrialRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 320, 87, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_StarRiverTrialIconItem, 87, 87, 1);
	self.rewardList:setLocation(51, 0, 0);
	self.rewardList:setCellSpacing(5, 0);
	self:setSubList(self.rewardList);
end

function Lua_StarRiverTrialRewardItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	if data.rank_left == data.rank_right then
		self.rankBg:setAltas("common_altas_4", "xui_jys_label_1"..(tonumber(data.rank_left) - 1));
		self.rankNumTxt:setEnable(false);
	else
		self.rankNumTxt:setEnable(true);
		self.rankBg:setAltas("common_altas_4", "xui_jys_label_13");
		local rightStr = data.rank_right == 0 and "+" or "-"..data.rank_right;
		self.rankNumTxt.text = data.rank_left..rightStr;
	end

	self.rewardList:setArrayData(data.rank_reward);
	self.rewardList.canDrag = #data.rank_reward > 3;
end

function Lua_StarRiverTrialRewardItem:checkClick()
	local winPos = LuaUtil.getTouchPosInverseObj(self.rewardList.sub);
	for i = 1, self.rewardList.showList:getSize() do
		if self.rewardList.showList[i]:checkInBound(winPos.x, winPos.y) then
			return self.rewardList.showList[i];
		end
	end
	return nil;
end

function Lua_StarRiverTrialRewardItem:onMouseDownHandle()
	if #self.data.rank_reward > 3 then
		return;
	end

	self.pressItem = self:checkClick();
	if self.pressItem ~= nil then
		self.pressItem:onMouseDownHandle();
	end
end

function Lua_StarRiverTrialRewardItem:onMouseUpHandle()
	if #self.data.rank_reward > 3 then
		return;
	end

	if self.pressItem ~= nil then
		self.pressItem:onMouseUpHandle();
	end
end

function Lua_StarRiverTrialRewardItem:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.pressItem ~= nil then
		self.pressItem:dispose();
		self.pressItem = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end










Lua_StarRiverTrialIconItem = class("Lua_StarRiverTrialIconItem", Lua_ListCell)
function Lua_StarRiverTrialIconItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_StarRiverTrialIconItem:buildShowItem()
	self:superCall("buildShowItem");

    self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.7, 0.7);
end

function Lua_StarRiverTrialIconItem:setData(data)
	if self.tvo == nil then
		self.tvo = Lua_ToolVo.createToolVo(data[1], data[2]);
	else
		self.tvo:setData(data[1], data[2]);
	end
	self.itemIcon:setData(self.tvo);
	self.itemIcon:setScale(0.7, 0.7);
end

function Lua_StarRiverTrialIconItem:onPressClick()
	self.itemIcon:onItemClick();
end

function Lua_StarRiverTrialIconItem:onMouseDownHandle()
	self.itemIcon:setScale(0.65, 0.65);
end

function Lua_StarRiverTrialIconItem:onMouseUpHandle()
	self.itemIcon:setScale(0.7, 0.7);
end

function Lua_StarRiverTrialIconItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:superCall("dispose");
end